<?php

/**
 * @file
 * Contains \Drupal\custom_pub\Entity\CustomPublishingOption.
 */

namespace Drupal\custom_pub\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\custom_pub\CustomPublishingOptionInterface;

/**
 * Defines the Custom publishing option entity.
 *
 * @ConfigEntityType(
 *   id = "custom_publishing_option",
 *   label = @Translation("Custom publishing option"),
 *   handlers = {
 *     "list_builder" = "Drupal\custom_pub\CustomPublishingOptionListBuilder",
 *     "form" = {
 *       "add" = "Drupal\custom_pub\Form\CustomPublishingOptionForm",
 *       "edit" = "Drupal\custom_pub\Form\CustomPublishingOptionForm",
 *       "delete" = "Drupal\custom_pub\Form\CustomPublishingOptionDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\custom_pub\CustomPublishingOptionHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "custom_publishing_option",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/admin/config/content/custom_publishing_option/{custom_publishing_option}",
 *     "add-form" = "/admin/config/content/custom_publishing_option/add",
 *     "edit-form" = "/admin/config/content/custom_publishing_option/{custom_publishing_option}/edit",
 *     "delete-form" = "/admin/config/content/custom_publishing_option/{custom_publishing_option}/delete",
 *     "collection" = "/admin/config/content/custom_publishing_option"
 *   }
 * )
 */
class CustomPublishingOption extends ConfigEntityBase implements CustomPublishingOptionInterface {

  /**
   * The option ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The option label.
   *
   * @var string
   */
  protected $label;

  /**
   * The option description.
   * @var string
   */
  protected $description;

  /**
   * The node types this option is enabled for.
   * @var array
   */
  protected $types;

  /**
   * Return the description of this option.
   */
  public function getDescription() {
    return $this->description;
  }

  /**
   * Return the applicable node types enabled for this option.
   * @return array
   */
  public function getNodeTypes() {
    return $this->types;
  }
}
